spoon.routing.NodeUnreachable

Package spoon :: Package routing :: Class NodeUnreachable |
[show private | hide private]
[frames | no frames]

## Class NodeUnreachable

           Exception --+
                       |
    RoutingProtocolError --+
                           |
                          NodeUnreachable

Raised when trying to send to a node that is not currently reachable. This is not necessarily a permanent condition. Particularly if a transport has just been lost, a node may become available again within a few seconds as a new route is found.

Method Summary
| `__init__(self, data, nodeId)`
Inherited from Exception
| ``__getitem__`(...)`
| ``__str__`(...)`

Generated by Epydoc 2.1 on Sun Nov 26 15:27:51 2006 | http://epydoc.sf.net